@@ -65,12 +65,15 @@ CUSUM <- function(x, method = "kernel", control = list(), inverse = "Cholesky",
       x.adj[(k+1):n] <- x.adj[(k+1):n] - mean(x[(k+1):n]) + mean(x[1:k])
       rho <- cor(x.adj[-n], x.adj[-1], method = "spearman")
       
+      param <- max(ceiling(n^(1/3) * ((2 * rho) / (1 - rho^2))^(2/3)), 1)
+      param <- min(param, n-1)
+
       if(method == "kernel")
       {
-        control$b_n <- max(ceiling(n^(1/3) * ((2 * rho) / (1 - rho^2))^(2/3)), 1)
+        control$b_n <- param
       } else if(method == "subsampling")
       {
-        control$l <- max(ceiling(n^(1/3) * ((2 * rho) / (1 - rho^2))^(2/3)), 1)
+        control$l <- param
       }
     }
     
